export declare type Address = string;
export declare type Port = number;
/**
 * Represents augmented data that includes metadata such as timestamps and message direction to be sent over the network.
 */
export interface AugmentedData {
    data: unknown;
    UUID: string;
    PORT: Port;
    ADDRESS?: Address;
    sendTime: number;
    receivedTime: number;
    replyTime: number;
    replyReceivedTime: number;
    timeout: number;
    msgDir: 'ask' | 'tell' | 'resp';
}
export declare const NewAugData: (data: unknown, UUID: string, port: number, address: string, timeoutInMs: number, msgDir: 'ask' | 'tell' | 'resp') => AugmentedData;
export declare type SnOpts = {
    port: number;
    address?: string;
    senderOpts?: {
        useLruCache?: boolean;
        lruSize: number;
    };
    headerOpts?: {
        sendHeaderVersion: number;
    };
    customStringifier?: (val: any) => string;
    customJsonParser?: (value: string) => any;
    crypto: {
        hashKey: string;
        signingSecretKeyHex: string;
    };
    payloadOpts?: {
        payloadSizeLimitInBytes?: number;
        headerSizeLimitInBytes?: number;
    };
};
/**
 * Validates the provided options object for the SnOpts type.
 * @param opts - The options object to validate.
 * @throws An error if the options object is not valid.
 */
export declare const validateSnOpts: (opts: SnOpts) => void;
export interface RemoteSender {
    address: string | undefined;
    port: number | undefined;
}
export declare type ResponseCallback = (data?: unknown, header?: AppHeader, sign?: Sign) => void;
export declare type ListenerResponder = (data?: unknown, header?: AppHeader) => void;
export declare type TimeoutCallback = () => void;
export declare type ListenCallback = (data: unknown, remote: RemoteSender, respond: ResponseCallback) => void;
export interface AppHeader {
    sender_id?: string;
    tracker_id?: string;
    verification_data?: string;
    compression?: string;
}
export interface CombinedHeader {
    uuid: string;
    sender_id?: string;
    tracker_id?: string;
    verification_data?: string;
    compression?: string;
}
export declare type CompressionTechnique = 'Gzip' | 'Brotli';
export interface Sign {
    owner: string;
    sig: string;
}
export declare type GetSenderAddressResult = {
    address: string;
    isValid: boolean;
    gasValid: boolean;
};
