"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateSnOpts = exports.NewAugData = void 0;
const NewAugData = (data, UUID, port, address, timeoutInMs, msgDir) => {
    // Under the hood, sn needs to pass around some extra data for its own internal usage.
    return {
        data,
        UUID,
        PORT: port,
        ADDRESS: address,
        sendTime: Date.now(),
        receivedTime: 0,
        replyTime: 0,
        replyReceivedTime: 0,
        timeout: timeoutInMs,
        msgDir,
    };
};
exports.NewAugData = NewAugData;
/**
 * Validates the provided options object for the SnOpts type.
 * @param opts - The options object to validate.
 * @throws An error if the options object is not valid.
 */
const validateSnOpts = (opts) => {
    if (!opts)
        throw new Error('snq: must supply options');
    const validations = [
        { condition: !opts.port || typeof opts.port !== 'number', message: 'snq: must supply port' },
        {
            condition: !opts.crypto.hashKey || typeof opts.crypto.hashKey !== 'string',
            message: 'snq: must supply hashKey',
        },
        {
            condition: opts.senderOpts?.useLruCache && !opts.senderOpts.lruSize,
            message: 'snq: must supply lruSize when using lruCache',
        },
        {
            condition: opts.payloadOpts?.payloadSizeLimitInBytes && typeof opts.payloadOpts.payloadSizeLimitInBytes !== 'number',
            message: 'snq: payloadSizeLimitInBytes must be a number',
        },
        {
            condition: opts.payloadOpts?.headerSizeLimitInBytes && typeof opts.payloadOpts.headerSizeLimitInBytes !== 'number',
            message: 'snq: headerSizeLimitInBytes must be a number',
        },
    ];
    for (const { condition, message } of validations) {
        if (condition)
            throw new Error(message);
    }
};
exports.validateSnOpts = validateSnOpts;
//# sourceMappingURL=types.js.map