"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NewNumberHistogram = exports.Histogram = void 0;
const crypto_1 = require("crypto");
const __1 = require("..");
class Histogram {
    constructor(bucketRanges, comparator) {
        this.bucketRanges = bucketRanges;
        this.comparator = comparator;
        this.buckets = new Map();
        this.initializeBuckets();
    }
    initializeBuckets() {
        for (let i = 0; i < this.bucketRanges.length; i++) {
            const rangeStart = this.bucketRanges[i];
            const rangeEnd = this.bucketRanges[i + 1] || Number.POSITIVE_INFINITY;
            this.buckets.set(`${rangeStart}-${rangeEnd}`, 0);
        }
    }
    logData(value) {
        for (const [bucket, count] of this.buckets.entries()) {
            const [rangeStart, rangeEnd] = bucket.split('-').map(Number);
            if (this.comparator(value, rangeStart, rangeEnd)) {
                this.buckets.set(bucket, count + 1);
                break;
            }
        }
    }
    clearHistogram() {
        for (const bucket of this.buckets.keys()) {
            this.buckets.set(bucket, 0);
        }
    }
    printHistogram(name = 'Histogram') {
        const printId = (0, crypto_1.randomUUID)();
        let logMessage = `\n${name}\n`;
        for (const [bucket, count] of this.buckets.entries()) {
            logMessage += `\t- ${bucket}: ${count}\n`;
        }
        console.log(logMessage);
    }
}
exports.Histogram = Histogram;
const NewNumberHistogram = (name, bucketRanges) => {
    const histogram = new Histogram(bucketRanges, (value, rangeStart, rangeEnd) => {
        return value >= rangeStart && value < rangeEnd;
    });
    setInterval(() => {
        /* prettier-ignore */ if (__1.logFlags.net_stats)
            histogram.printHistogram(name);
        /* prettier-ignore */ if (__1.logFlags.net_stats)
            histogram.clearHistogram();
    }, 10 * 60 * 1000);
    return histogram;
};
exports.NewNumberHistogram = NewNumberHistogram;
//# sourceMappingURL=Histogram.js.map