"use strict";
// import { time } from 'console'
Object.defineProperty(exports, "__esModule", { value: true });
exports.TTLMap = void 0;
class TTLMap {
    constructor() {
        this.map = {};
    }
    set(key, value, ttl, onExpiry) {
        const expiry = Date.now() + ttl;
        const timeoutId = setTimeout(() => {
            if (onExpiry) {
                onExpiry(key, value);
            }
            delete this.map[key];
        }, ttl);
        this.map[key] = { value, expiry, timeoutId };
    }
    get(key) {
        const value = this.map[key];
        if (value && value.expiry > Date.now()) {
            return value.value;
        }
        delete this.map[key];
        return undefined;
    }
    delete(key) {
        const entry = this.map[key];
        if (entry && entry.timeoutId) {
            clearTimeout(entry.timeoutId);
        }
        delete this.map[key];
    }
}
exports.TTLMap = TTLMap;
//# sourceMappingURL=TTLMap.js.map